pub struct RuntimeError { /* private fields */ }Expand description
A struct representing an aborted instruction execution, with a message indicating the cause.
Implementations
Sourceimpl RuntimeError
impl RuntimeError
Sourcepub fn new<I: Into<String>>(message: I) -> Self
pub fn new<I: Into<String>>(message: I) -> Self
Creates a new generic RuntimeError with the given message.
Example
let trap = wasmer_engine::RuntimeError::new("unexpected error");
assert_eq!("unexpected error", trap.message());Sourcepub fn raise(error: Box<dyn Error + Send + Sync>) -> !
👎Deprecated since 2.1.1: return a Result from host functions instead
pub fn raise(error: Box<dyn Error + Send + Sync>) -> !
return a Result from host functions instead
Raises a custom user Error
Sourcepub fn user(error: Box<dyn Error + Send + Sync>) -> Self
pub fn user(error: Box<dyn Error + Send + Sync>) -> Self
Creates a custom user Error.
This error object can be passed through Wasm frames and later retrieved
using the downcast method.
Sourcepub fn trace(&self) -> &[FrameInfo]
pub fn trace(&self) -> &[FrameInfo]
Returns a list of function frames in WebAssembly code that led to this trap happening.