pub trait Resolver {
// Required method
fn resolve(&self, _index: u32, module: &str, field: &str) -> Option<Export>;
}Expand description
Import resolver connects imports with available exported values.
Required Methods
Sourcefn resolve(&self, _index: u32, module: &str, field: &str) -> Option<Export>
fn resolve(&self, _index: u32, module: &str, field: &str) -> Option<Export>
Resolves an import a WebAssembly module to an export it’s hooked up to.
The index provided is the index of the import in the wasm module
that’s being resolved. For example 1 means that it’s the second import
listed in the wasm module.
The module and field arguments provided are the module/field names
listed on the import itself.
Notes:
The index is useful because some WebAssembly modules may rely on that for resolving ambiguity in their imports. Such as:
ⓘ
(module
(import "" "" (func))
(import "" "" (func (param i32) (result i32)))
)Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".